@@ -1,6 +1,6 @@
 rad.labels <- 
 function(ref=NULL, data=FALSE, labels=TRUE, ...) {
          
-  rad(ref, data=FALSE, labels=TRUE, ...)
+  Read(ref, data=FALSE, labels=TRUE, ...)
 
 }
