@@ -1,5 +1,5 @@
 tt.brief <-
 function(..., brief=TRUE)
 
-tt(..., brief=TRUE)
+ ttest(..., brief=TRUE)
 
